from setuptools import setup

setup(
    name = "Gamwo",
    packages = ['gamwo'],
    version = '0.1.1',
    description = 'Simple python framework for 2d games',
    long_description= 'There isnt much to say about this package',
    long_description_content_type='text/markdown',
    author='RinkaDev',
    author_email='rinkadevoficial@gmail.com',
    url='https://github.com/RinkaGI/Gamwo',
    keywords=['game', 'framework', '2d', 'simple', 'pygame'],
    classifiers=[ ],
    license='MIT',
    include_package_data=True
)